# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.3](https://github.com/jdrouet/mrml/compare/css-compare-v0.1.2...css-compare-v0.1.3) - 2024-06-13

### Other
- *(deps)* Bump rustls from 1.0.0-alpha.46 to 1.0.0-alpha.55

## [0.1.2](https://github.com/jdrouet/mrml/compare/css-compare-v0.1.1...css-compare-v0.1.2) - 2024-03-21

### Other
- switch license to MIT ([#388](https://github.com/jdrouet/mrml/pull/388))

## [0.1.1](https://github.com/jdrouet/mrml/compare/css-compare-v0.1.0...css-compare-v0.1.1) - 2023-12-01

### Other
- bump deps ([#328](https://github.com/jdrouet/mrml/pull/328))
